<?php
/*
Supasite - web based PHP/mySQL/XML content management tool
Copyright (C) 2001 - Rick Olson (rick@techno-weenie.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

SCRIPT NAME:  admin_users.php (frontend)
DESC:  manages users
*/

require_once("$supa[db_path]/$supa[db]_users.php");

/* FRONT END FUNCTIONS */
function supa_users_add() {
  global $HTTP_POST_VARS;
  $supa = &$GLOBALS['supa'];

  if(!$HTTP_POST_VARS['submit']) {
    $supa["title"] = "Add User";
    $supa["content"] = add_user_form(); # show the form
  } else {
    $supa["title"] = "Adding User";
    $supa["content"] = add_user($HTTP_POST_VARS[user], $HTTP_POST_VARS[pass], $HTTP_POST_VARS[priv], $HTTP_POST_VARS[email]);
  }
}

function supa_users_list() {
  global $login;
  $supa = &$GLOBALS['supa'];

  if($login[priv] <= 2) { # verify that they have permissions to list the users
    $supa["title"] = "List Users";
    $supa["content"] = list_users();
  } else {
    $supa["title"] = "Change Profile for $login[username]";
    $supa["content"] = edit_user_form($login[id], "You do not have permissions to manage other users.");
  }
}

function supa_users_edit() {
  global $id, $login, $HTTP_POST_VARS;
  $supa = &$GLOBALS['supa'];

  if(($id) && ($login[priv] <= 2)){ # ID is good... priv is good
    if(!$HTTP_POST_VARS['submit']) { # has not been submitted
      $supa["title"] = "Edit User $id";
      $supa["content"] = edit_user_form($id);
    } else {
      $supa["title"] = "Editing User $id";
      $supa["content"] = edit_user($id, $HTTP_POST_VARS[user], $HTTP_POST_VARS[pass], $HTTP_POST_VARS[email], $HTTP_POST_VARS[priv]);
    }
  } elseif (!$id) { # ID is bad
    $supa["title"] = "Oops...";
    $supa["content"] = list_users("User ID is invalid.");
  } elseif ($login[priv] > 1) { # bad privileges
    $supa["title"] = "Oops...";
    $supa['content'] = list_users("You do not have proper privileges to edit a user.");
  }
}

function supa_users_delete() {
  global $conf, $id;
  $supa = &$GLOBALS['supa'];

  if($conf != "yes") { # not confirmed
    $supa["title"] = "Delete user $id?";
  } else { # delete is CONFIRMED
    $supa["title"] = "Deleting user $id...";
  }
  $supa["content"] = delete_user($id, $conf);
}

function supa_users_profile() {
  global $login, $HTTP_POST_VARS;
  $supa = &$GLOBALS['supa'];

  $supa["title"] = "Change Profile for $login[username]";
  if(!$HTTP_POST_VARS['submit'])
    $supa["content"] = edit_user_form($login[id]);
  else
    $supa["content"] = edit_user($login[id], $HTTP_POST_VARS[user], $HTTP_POST_VARS[pass], $HTTP_POST_VARS[email], $HTTP_POST_VARS[priv]);
}

### BACKEND FUNCTIONS ###

### display the add user form ###
function add_user_form($msg = '') {
  global $login;
  if($login[priv] <= 2) {
    if($msg != "") {
      $form = common_status("$msg");
    }
    $form .= "<form action=\"index.php\" method=\"POST\">\n";
    $form .= "<p><b>Username</b>:   <input type=\"text\" name=\"user\" size=\"40,1\" /><br/>\n";
    $form .= "<b>Password</b>:    <input type=\"password\" name=\"pass\" size=\"40,1\" /><br/>\n";
    $form .= "<b>Email</b>:     <input type=\"text\" name=\"email\" size=\"40,1\" /><br/>\n";
    $form .= "<b>news poster</b> - <input type=\"radio\" name=\"priv\" value=\"3\" checked=\"checked\" /><br/>\n";
    $form .= "<b>editor</b> - <input type=\"radio\" name=\"priv\" value=\"2\" /><br/>\n";
    $form .= "<b>superuser</b> - <input type=\"radio\" name=\"priv\" value=\"1\" /><br/>\n";
    $form .= "<input type=\"hidden\" name=\"act\" value=\"users_add\" />\n";
    $form .= "<input type=\"submit\" value=\"Add User\" name=\"submit\" class=\"submit\" /></p></form>\n";

    $form .= list_users();
    return $form;
  } else {
    return common_status("You do not have proper privilege to add a user.");
  }
}

### list users from the database ###
function list_users($msg = '') {
  global $login;
  if($msg != '')
    $list .= common_status($msg);

  $res = data_getUserInfo();
  while( list($null, $row) = each($res) ) {
    if($row[priv] == 1)
      $row['username'] = "<b>$row[username]</b> "; ### if super user, display it in bold

    if(($row[priv] > 1) || ( ($row[priv] == 1) && ($login[priv] == 1) ))
      $list .= "$row[username] - $row[email] [ <a href=\"index.php?act=users_edit&amp;id=$row[id]\">edit</a> | <a href=\"index.php?act=users_delete&amp;id=$row[id]\">delete</a> ]<br />\n";
  }
  return "<p>".$list."</p>\n\n";
}

### add user to the database ###
function add_user($new_user, $new_pass, $priv, $email) {
  global $login;

  $x = data_getUserID($new_user);
  if( ($priv != 1) && ($priv != 2) )
    $priv = 3;

  if($x > 0)
    $err = "No user added, there's already a user with the name <b>$new_user</b>.";

  if($new_user == '')
    $err = "No user added.  Fill in the username box.";

  if(!$err) {
    # password is sent clear text
    if(backend_addUser($login[username], $login[password], $new_user, $new_pass, $priv, $email))
      return add_user_form("User <b>$new_user</b> added successfully.");
    else
      return common_status("Errors adding new user.");
  } else {
    return add_user_form($err);
  }
}


### display form to edit the user ###
function edit_user_form($id, $msg = '') {
  global $login, $act;

  $profile = data_getUserInfo($id);
  $profile = $profile[0];
  if( ($login[priv] == 1) || ( ($login[priv] == 2) && ($profile[priv] != 1) ) || ($login[id] == $id) ) { # if super user or it's the user's profile
    if($msg)
      $form .= common_status($msg);

    list($null, $user_arr) = each( data_getUserInfo($id) );
    $priv = $user_arr[priv];
    $radio[$priv] = " checked=\"checked\"";

    $form .= "<form action=\"index.php\" method=\"POST\">\n";
    $form .= "<p><b>Username</b>:   <input type=\"text\" name=\"user\" value=\"$user_arr[username]\" size=\"40,1\"><br/>\n";
    $form .= "<b>Password</b>:    <input type=\"password\" name=\"pass\" value=\"********\" size=\"40,1\"><br/>\n";
    $form .= "<b>Email</b>:     <input type=\"text\" name=\"email\" value=\"$user_arr[email]\" size=\"40,1\"><br/>\n";

    if($login[priv] <= 2) {
      $form .= "<b>news poster</b> - <input type=\"radio\" name=\"priv\" value=\"3\"$radio[3] /><br/>\n";
      $form .= "<b>editor</b> - <input type=\"radio\" name=\"priv\" value=\"2\"$radio[2] /><br/>\n";
      $form .= "<b>superuser</b> - <input type=\"radio\" name=\"priv\" value=\"1\"$radio[1] /><br/>\n";
    }

    $form .= "<input type=\"hidden\" name=\"act\" value=\"users_edit\">\n";
    $form .= "<input type=\"hidden\" name=\"id\" value=\"$id\">\n";
    $form .= "<input type=\"submit\" value=\"Edit $row[0]\" name=\"submit\" class=\"submit\"></p></form>\n";

    if($login[priv] <= 2)
      $form .= list_users();
    return $form;
  } else {
    return list_users("You do not have the proper privileges.");
  }
}

### update user info in the database ###
function edit_user($id, $new_user, $new_pass, $email, $priv) {
  global $login, $act;
  if( ($login[priv] <= 2) || (($act == 'users_profile') && ($login[id] == $id)) ) {
    if( (data_getUserID($new_user)) && ($new_user != data_getUser($id)) ) {
      return edit_user_form($id, "User info not edited, there's already a user with the name <b>$new_user</b>.");
    } else {
      # password sent in plain text again #
      if(backend_editUser($login[username], $login[password], $id, $new_user, $new_pass, $email, $priv))
        return edit_user_form($id, "User $new_user edited successfully.");
      else
        return edit_user_form($id, 'User not edited successfully.');
    }
  } else {
    return common_status("You do not have the proper privilege to edit a user.");
  }
}

### delete user from the database ###
function delete_user($id, $conf = 'no') {
  global $login;

  $profile = data_getUserInfo($id);
  $profile = $profile[0];
  if(($login[priv] == 1) || ( ($login[priv] == 2) && ($profile[priv] != 1) )) {
    if($conf != "yes") { # delete is not confirmed
      list($null, $row) = each( data_getUserInfo($id) );
      if($row[priv] == 1) { $super = "<b>super user</b>"; }
      return common_status("Delete $super <a href=\"mailto:$row[email]\">$row[username]</a>?<br />\n<a href=\"index.php?act=users_delete&amp;id=$id&amp;conf=yes\">yes</a>").list_users();
    } else { # delete is CONFIRMED
      if(backend_deleteUser($login[username], $login[password], $id))
        return list_users("User $id deleted...");
      else
        return list_users("User $id not deleted...");
    }
  } else {
    return list_users("You do not have the proper privileges.");
  }
}
?>