<?php
/*
Supasite - web based PHP/mySQL/XML content management tool
Copyright (C) 2001 - Rick Olson (rick@techno-weenie.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

SCRIPT NAME:  admin_utilities (frontend)
DESC:  defines different utilities, like site stats, etc
*/

require_once("$supa[db_path]/$supa[db]_utilities.php");

/* front end functions are declared in settings.php */

/* *** BACKEND FUNCTIONS *** */

### displays main page of stats ###
function utilities_serverStats($msg = '') {
  if($msg != '')    $content = common_status($msg);
  return $content."<table cellpadding=\"10\">\n<tr>\n\t<td valign=\"top\">\n".display_left_stats()."\t</td>\n\t<td valign=\"top\">\n".display_server_stats()."\t</td>\n</tr>\n</table>\n\n";
}

### deletes posts w/ invalid ID
function utilities_fixDates($username, $password) {

  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $row_count = backend_fixBadDates($username, $password);
    if($row_count != '1')  {
      $plural = 's';
      $h = 'have';
    } else {
      $h = 'has';
    }

    return utilities_serverStats("$row_count post$plural with an invalid datetime $h been deleted.");
  }
}

### deletes posts w/ invalid ID
function utilities_fixPosts($username, $password, $action = 'delete') {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $row_count = backend_fixBadPosts($username, $password, $action);
    if($row_count != '1')  {
      $plural = 's';
      $h = 'have';
    } else {
      $h = 'has';
    }
    if($action == 'fix')
      $verb = "fixed.";
    else
      $verb = "deleted.";
    return utilities_serverStats("$row_count post$plural with an invalid ID $h been $verb");
  }
}

### deletes comments w/ invalid root, displays main page of stats ###
function utilities_delRoot($username, $password) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $row_count = backend_fixBadComments($username, $password);
    if($row_count != '1')  {
      $plural = 's';
      $h = 'have';
    } else {
      $h = 'has';
    }
    utilities_countComments($username, $password);
    return utilities_serverStats("$row_count comment$plural with an invalid root ID $h been deleted.");
  } else {
    return common_status("Bad username/password.");
  }
}

### counts comments and matches it against the news table ###
function utilities_countComments($username, $password) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $fix_count = backend_countComments($username, $password);
    if($fix_count != '1')   $plural = 's';
    return utilities_serverstats("$fix_count post$plural with an invalid comment count has been fixed.");
  } else {
    return common_status("Bad username/password.");
  }
}

### optimizes all tables ###
function utilities_optimize($username, $password, $tbl) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    if($tables = backend_optimizeTables($username, $password, $tbl))
      return utilities_serverstats("Table optimization complete.  Optimized $tables.");
    else
      return utilities_serverstats("Errors optimizing $tables.");
  } else {
    return common_status("Bad username/password.");
  }
}

### fixes posts with invalid user ids ###
function utilities_fixUsers($username, $password, $u_id) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $user_count = backend_fixUsers($username, $password, $u_id);
    if($user_count != '1')    $plural = 's';
    return utilities_serverStats("$user_count post$plural with an invalid UserID have been fixed.");
  } else {
    return common_status("Bad username/password.");
  }
}

### fixes posts with invalid topic ids ###
function utilities_fixTopics($username, $password, $t_id) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    $topic_count = backend_fixTopics($username, $password, $t_id);
    if($topic_count != '1')   $plural = 's';
    return utilities_serverStats("$topic_count post$plural with an invalid TopicID have been fixed.");
  } else {
      return common_status("Bad username/password.");
  }
}

### UTILITY FUNCTIONS ###

/* ------------ used in SERVER STATS ------------------ */
### display stats about the server ###
function display_server_stats($msg = '') {
  /* NOW, print the stats */
  $server_stats .= "<p><b>Current PHP Version</b>: ".phpversion()."<br />\n";
  $server_stats .= "<b>Server API</b>: ".php_sapi_name()."</p>\n\n";

  $server_stats .= "<p class=\"small\">\n";
  $server_stats .= "<a href=\"index.php?act=settings_fix_posts&amp;action=fix\">--&gt;</a> FIX posts with invalid post ID.<br />\n";
  $server_stats .= "<a href=\"index.php?act=settings_fix_posts&amp;action=delete\">--&gt;</a> DELETE posts with invalid post ID.<br />\n";
  $server_stats .= "<a href=\"index.php?act=settings_fix_dates\">--&gt;</a> DELETE posts with invalid datetime.<br />\n";
  $server_stats .= "<a href=\"index.php?act=settings_del_root\">--&gt;</a> DELETE comments with invalid root id.<br />\n";
  $server_stats .= "<a href=\"index.php?act=settings_count_comments\">--&gt;</a> FIX posts with invalid comment counts<br />\n";

  $server_stats .= "<form action=\"index.php\" method=\"POST\"><p style=\"margin:0\" class=\"small boxedarea\">\n";
  $server_stats .= "Optimize\n";
  $server_stats .= "<select name=\"tbl\" class=\"small\">\n";
  $server_stats .= "  <option value=\"1\">all tables</option>\n";
  $table_list = backend_returnTableList();
  foreach($table_list as $table) {
    $server_stats .= "  <option value=\"$table\">$table</option>\n";
  }
  $server_stats .= "</select>\n\n";
  $server_stats .= "<input type=\"hidden\" name=\"act\" value=\"settings_optimize\" />\n";
  $server_stats .= "<input type=\"submit\" name=\"submit\" value=\"&gt;\" class=\"small\" /></p></form><br />\n\n";

  $server_stats .= "<form action=\"index.php\" method=\"POST\" ><p style=\"margin:0\" class=\"small boxedarea\">\n";
  $server_stats .= "convert posts with invalid user id.<br />\n[ set to user\n";
  $server_stats .= "<input type=\"hidden\" name=\"act\" value=\"settings_fix_users\" />\n";
  $server_stats .= "<select name=\"u_id\" class=\"small\">\n";
  $u_array = data_getUserList();
  foreach($u_array as $u) {
    $server_stats .= "<option value=\"$u\">$u</option>\n";
  }
  $server_stats .= "</select>\n<input type=\"submit\" name=\"submit\" value=\"&gt;\" class=\"small\" /> ]\n";
  $server_stats .= "</p></form><br />\n\n";

  $server_stats .= "<form action=\"index.php\" method=\"POST\" ><p style=\"margin:0\" class=\"small boxedarea\">\n";
  $server_stats .= "convert posts with invalid topic id.<br />\n[ set to topic\n";
  $server_stats .= "<input type=\"hidden\" name=\"act\" value=\"settings_fix_topics\" />\n";
  $server_stats .= "<select name=\"t_id\" class=\"small\">\n";
  $t_array = data_getTopicList();
  foreach($t_array as $t) {
    $server_stats .= "<option value=\"$t\">$t</option>\n";
  }
  $server_stats .= "</select>\n<input type=\"submit\" name=\"submit\" value=\"&gt;\" class=\"small\" /> ]\n";
  $server_stats .= "</p></form>\n\n";

  return $server_stats;
}

function display_left_stats() {
  return display_news_stats()
    . display_user_stats()
    . display_topic_stats()
    . display_view_stats()
    . display_comment_stats();
}

### display stats about the news ###
function display_news_stats() {
  global $site;
  ### counting posts ###
  $count = data_countPosts($site[newsage]);
  if($count[posts] != 1)
    $post_s = 's';
  if($count[pages] != 1)
    $page_s = 's';

  ### counting comments ###
  $num_comments = data_countComments();
  if($num_comments != 1)
    $comment_s = 's';

  ### getting the first posted date ###
  $news_stats = "<p style=\"margin:0\"><b>Site News Stats</b> <small>since ".data_firstDate()."</small><br />\n";
  $news_stats .= "$count[posts] post$post_s in $count[pages] page$page_s.<br />\n";
  $news_stats .= "$num_comments comment$comment_s posted.</p>\n\n";

  return $news_stats;
}

### getting number of posts by username ###
function display_user_stats() {
  $uidcount = backend_countPostsByUser();
  ### display the results ###
  foreach($uidcount as $u=>$count) {
    if($count != 1)
      $plural = 's';
    $user_stats .= "<i>$u</i> has made $count post$plural.<br />\n";
  }

  return "<p><b>News Posts</b> <small>by username</small><br />\n$user_stats</p>\n\n";
}

### getting number of posts by topic ###
function display_topic_stats() {
  $tidcount = backend_countPostsByTopic();
  ### display the results ###
  foreach($tidcount as $t=>$count) {
    if($count != 1)   $plural = 's have';
    else                  $plural = ' has';
    $topic_stats .= "$count post$plural been made in <i>$t</i>.<br />\n";
  }

  return "<p><b>News Posts</b> <small>by topic</small><br />\n$topic_stats</p>\n\n";
}

### getting number of posts by views ###
function display_view_stats() {
  global $supa, $site;

  $res = backend_sortByViews(5);
  while(list($id, $row) = each($res)) {
    $url = "$supa[web_path]/$site[news_script]/view/$id";
    if($row[views] != '1')    $plural = 's';
    $view_stats .= "<a href=\"$url\">$row[subject]</a> - $row[views] view$plural <small>on $row[date]</small><br />\n";
    unset($plural);
  }

  return "<p><b>News Posts</b> <small>by views</small><br />\n$view_stats</p>\n\n";
}

### getting number of posts by views ###
function display_comment_stats() {
  global $supa, $site;

  $res = backend_sortByComments(5);
  while(list($id, $row) = each($res)) {
    $url = "$supa[web_path]/$site[news_script]/view/$id";
    if($row[comments] != '1')    $plural = 's';
    $view_stats .= "<a href=\"$url\">$row[subject]</a> - $row[comments] comment$plural <small>on $row[date]</small><br />\n";
    unset($plural);
  }

  return "<p><b>News Posts</b> <small>by number of comments</small><br />\n$view_stats</p>\n\n";
}
?>