<?php
/*
Supasite - web based PHP/mySQL/XML content management tool
Copyright (C) 2001 - Rick Olson (rick@techno-weenie.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

SCRIPT NAME:  common_functions.php (frontend)
DESC:  Declares basic functions for use throughout the whole site and the common xml classes
*/

### this is set here so I can change the version w/o changing the config.php script ###
$supa["version"] = "Supasite v1.23b";
require_once("$supa[db_path]/$supa[db]_api.php");
### ETC ###

### returns 3 letter month abbrev given a number ###
function common_getMonthName($num) {
  return date('M', mktime (0,0,0,$num,1,2001));
}

### prints a status message ###
function common_status($msg) {
  return "<p class=\"small center\">$msg</p>\n\n";
}

### encodes a string
function common_encodeString($string) {
  return base64_encode($string);
}

### decodes a string
function common_decodeString($string) {
  return base64_decode($string);
}

### formats the filesize of a file ###
function common_getFilesize($file) {
  $filesize = filesize($file);
  $units = array (' bytes', 'KB', 'MB', 'GB');
  $unit = 0;
  if($filesize > 0) {
    while($filesize >= pow(1024,$unit))
      $unit++;
    $unit--;
    return number_format($filesize / pow(1024,$unit), 2, '.', '') . $units[$unit];
  } else {
    return "0 bytes";
  }
}

/* autolinks URLs... not used quite yet though
 * function contributed by Ryan Christensen
 */
function common_urlFormat( $s ) {
  $o = '';
  while ($s != '') {
    $url = '';
    $temp = split('://', $s, 2);
    if (count($temp)>1) {
      $s = $temp[1];
      $temp2 = split('[^[:alpha:]]', strrev($temp[0]), 2);
      $schema = strrev($temp2[0]);
      $o .= substr($temp[0], 0, strlen($temp[0])-strlen($schema));
      if ($schema != '') {
        $temp3 = split("[[:space:],'\"<>:]", $s, 2);
        $url = $schema . '://' . $temp3[0];
        $ns = substr($s, strlen($temp3[0]),1) . $temp3[1];
        if ($temp3[0] != '') {
          $o .= "<a href=$url>$url</a>";
        } else {
          $o .= $url;
        }
        $s = $ns;
      }
      else {
        $o .= '://';
      }
    }
    else {
      $o .= $s;
      $s = '';
    }
  } // while
  return $o;
}

### formats data taken from the database
function common_outputEntry($entry) {
  return stripslashes(trim($entry));
}

### formats entry for for editing purposes ###
function common_editEntry($entry) {
  $entry = common_outputEntry($entry);
  /* puts an extra &amp; in front so in the TEXTAREA all you see is &lt; really (or whatever the code is) */
  $search = array("&amp;", "&lt;", "&gt;", "&nbsp;", "&#", "&apos", "&quot", "&deg;", "&cent;");
  $replace = array("&amp;amp;", "&amp;lt;", "&amp;gt;", "&amp;nbsp;", "&amp;#", "&amp;apos", "&amp;quot", "&amp;deg;", "&amp;cent;");
  for($i = 0; $i < count($search); $i++) { $entry = str_replace($search[$i], $replace[$i], $entry); }
  return $entry;
}

### DATA API ###

### the basic XML class ###
class xml {
  ### declare variables ###
  var $parser = '';
  var $output = '';
  var $stack = array();

  ### CONSTRUCTOR function that sets the XML options ###
  function xml($file) {
    $this->xml_file = $file;
    $this->parser = xml_parser_create();
    xml_parser_set_option($this->parser, XML_OPTION_CASE_FOLDING, 0);
      /*
       * the functions start_element(), stop_element(), and char_data() must be set
       * in an object class that extends this one.  See template_xml class in side.php
       * for an example.  see http://www.php.net/xml for more info
       */
    xml_set_element_handler($this->parser, "start_element", "stop_element");
    xml_set_character_data_handler($this->parser, "char_data");
  }

  ### other class functions ###

  ### returns the parent element ###
  function get_parent() {
    if($this->stack[count($this->stack)-1])
      return $this->stack[count($this->stack)-1];
    else
      return(false);
  }

  ### function that actually parses the file ###
  function parse_xml() {
    xml_set_object($this->parser, &$this);
    if(!($fp = @fopen($this->xml_file, "r"))) {
      die("Can't open file \"$this->xml_file\".");
    }

    while ($data = fread($fp, 4096)) {
      if (!xml_parse($this->parser, $data, feof($fp))) {
        $err_str = xml_error_string(xml_get_error_code($this->parser));
        $err_line = xml_get_current_line_number($this->parser);
        die("XML error: $err_str at line $err_line");
      }
    }
    fclose($fp);
    xml_parser_free($this->parser);
  }
}

### formats data being entered into the database
function data_inputEntry($entry) {
  return addslashes(trim($entry));
}

### formats news entry being insterted into the database
function data_formatEntry($entry) {
  global $linebreak;
  $entry = data_inputEntry($entry);
  #$entry = common_urlFormat($entry);
  if($linebreak == 'yes') { $entry = str_replace("\r\n", "<br />", $entry); }
  $entry = str_replace("\n", '', $entry); // all db entries must be on a single line...
  $entry = str_replace("\r", '', $entry);
  $search = array("&", "&amp;amp;", "&amp;lt;", "&amp;gt;", "&amp;nbsp;", "&amp;#", "&amp;apos", "&amp;quot", "&amp;deg;", "&amp;cent;");
  $replace = array("&amp;", "&amp;", "&lt;", "&gt;", "&nbsp;", "&#", "&apos", "&quot", "&deg;", "&cent;");
  for($i = 0; $i < count($search); $i++) { $entry = str_replace($search[$i], $replace[$i], $entry); }

  return $entry;
}

### formats comment entry being insterted into the database
function data_formatComment($entry) {
  global $site;
  $entry = strip_tags($entry, $site[tags]);
  $entry = data_inputEntry($entry);
  # common_urlFormat() is still being worked on...
  #$entry = common_urlFormat($entry);
  $search = array("\r\n", "&", "&amp;amp;", "&amp;lt;", "&amp;gt;", "&amp;nbsp;", "&amp;#", "&amp;apos", "&amp;quot");
  $replace = array("<br />", "&amp;", "&amp;", "&lt;", "&gt;", "&nbsp;", "&#", "&apos", "&quot");
  for($i = 0; $i < count($search); $i++) { $entry = str_replace($search[$i], $replace[$i], $entry); }

  return $entry;
}
?>