<?php
/*
Supasite - web based PHP/mySQL/XML content management tool
Copyright (C) 2001 - Rick Olson (rick@techno-weenie.com)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

SCRIPT NAME:  mysql_utilities.php (backend)
DESC: backend database functions for the utility functions
*/

### common UTILITY functions ###

### returns array of all post IDs ###
function backend_returnPostIDArray() {
  global $db;
  ### making array of valid root ids ###
  $res = $db->get_results("SELECT DISTINCT id FROM news;");
  while($row = $db->next_result(&$res)) {
    $arr[] = $row[id];
  }
  return $arr;
}

### returns array of all user IDs ###
function backend_returnUserIDArray() {
  global $db;
  ### making array of valid root ids ###
  $res= $db->get_results("SELECT DISTINCT id FROM usernames;");
  while($row = $db->next_result(&$res)) {
    $arr[] = $row[id];
  }
  return $arr;
}

### returns array of all topic IDs ###
function backend_returnTopicIDArray() {
  global $db;
  ### making array of valid root ids ###
  $res =  $db->get_results("SELECT DISTINCT id FROM news_topics;");
  while($row = $db->next_result(&$res)) {
    $arr[] = $row[id];
  }
  return $arr;
}

function backend_returnTableList() {
  global $db;
  $res = $db->list_tables($db->dbname);
  while($row = $db->fetch_row($res)) {
    $table_list[] = $row[0];
  }
  return $table_list;
}

### other functions ###

### delete posts with invalid post IDs
function backend_fixBadPosts($username, $password, $action = 'delete') {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    ### getting the max id
    $result = $db->get_results("SELECT max(id) as max FROM news;");
    $row = $db->next_result(&$result);
    $max_id = $row[max];

    $res = $db->get_results("SELECT id, datetime AS d FROM news;");
    $row_count = 0;
    while($row = $db->next_result(&$res)) {
      if(($row[id] < 1) || ($row[id] == '')) {
        if($action == 'fix') {
          ### giving the post a new id ###
          $max_id++; ### add one to the max
          $db->run_query("UPDATE news SET id = '$max_id' WHERE id = '$row[id]';");
        } else {
          ### deleting the post
          $db->run_query("DELETE FROM news WHERE id = '$row[id]' AND datetime = '$row[d]';");
        }
        $row_count++;
      }
    }
    return $row_count;
  } else {
    return 0;
  }
}

### delete posts with bad dates
function backend_fixBadDates($username, $password) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    $res = $db->get_results("SELECT id, datetime AS d FROM news;");
    $row_count = 0;
    while($row = $db->next_result(&$res)) {
      if(($row[d] == '') || ($row[d] == '0000-00-00 00:00:00')) {
        ### deleting the post
        $db->run_query("DELETE FROM news WHERE id = '$row[id]';");
        $row_count++;
      }
    }
    return $row_count;
  } else {
    return 0;
  }
}

### fix comments with invalid root id ###
function backend_fixBadComments($username, $password) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    ### getting comments with no root id ###
    $root_id = backend_returnPostIDArray();
    $row_count = 0;
    $res = $db->get_results("SELECT id, root AS r FROM comments;");
    while($row = $db->next_result(&$res)) {
      ### if root is < 0 or not set OR if it's not in the array of post IDs then it is a BAD COMMENT ###
      if(($row[r] == '') || ($row[r] < 1) || (!in_array($row[r], $root_id))) {
        $db->run_query("DELETE FROM comments WHERE id = '$row[id]';");
        $row_count++;
      }
    }
    return $row_count;
  } else {
    return 0;
  }
}

### fix news posts with invalid comment counts ###
function backend_countComments($username, $password) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db; $fix_count = 0;
    ### get posts with comments
    $res = $db->get_results("SELECT DISTINCT id, comments AS c FROM news;");
    while($row = $db->next_result(&$res)) {
        $count = data_countComments($row[id]);
        ### if a result is returned and it doesn't match the news table
        if($row[c] != $count) {
          $db->run_query("UPDATE news SET comments = '$count' WHERE id = '$row[id]';");
          $fix_count++;
        }
    }
    return $fix_count;
  } else {
    return 0;
  }
}

### optimize tables ###
function backend_optimizeTables($username, $password, $tbl = 'all') {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    if(($tbl == 1) || ($tbl == 'all')) # optimize all tables
      $tbl = backend_returnTableList();
    else # optimize just one table
      $tbl = array($tbl);

    $tables = $tbl[0]; # so there's no comma in the front like below
    for($i = 1; $i < count($tbl); $i++) {
      $tables .= ", $tbl[$i]";
    }

    if(!$db->run_query("OPTIMIZE TABLE $tables;"))
      return 0;
    else
      return $tables;
  } else {
    return 0;
  }
}

### fix posts with invalid user ids... $u_id is the user id to change the invalid posts to
function backend_fixUsers($username, $password, $u) {
  $u_id = data_getUserID($u);
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    ### making array of valid user ids ###
    $user_id = backend_returnUserIDArray();

    ### getting posts with invalid username ###
    $user_count = 0;
    $res = $db->get_results("SELECT id, user_id AS u FROM news;");
    while($row = $db->next_result(&$res)) {
      if(($row[u] == '') || ($row[u] < 1) || (!in_array($row[u], $user_id))) {
        $user_count++;
        $db->run_query("UPDATE news SET user_id = '$u_id' WHERE id = '$row[id]';");
      }
    }
    return $user_count;
  } else {
    return 0;
  }
}

### fix posts with invalid topic ids... $t_id is the topic id to change them to
function backend_fixTopics($username, $password, $t) {
  if( ($login = auth_login($username, $password)) && ($login[priv] == '1') ) {
    global $db;
    $t_id = data_getTopicID($t);
    ### making array of valid topic ids ###
    $topic_id = backend_returnTopicIDArray();

    ### getting posts with invalid username ###
    $topic_count = 0;
    $res = $db->get_results("SELECT id, topic_id AS t FROM news;");
    while($row = $db->next_result(&$res)) {
      if(($row[t] == '') || ($row[t] < 1) || (!in_array($row[t], $topic_id))) {
        $topic_count++;
        $db->run_query("UPDATE news SET topic_id = '$t_id' WHERE id = '$row[id]';");
      }
    }
    return $topic_count;
  } else {
    return 0;
  }
}

function backend_sortByViews($limit) {
  global $db, $site;
  return $db->get_results("SELECT id, subject, views, DATE_FORMAT(datetime, '$site[date_string]') AS date FROM news ORDER BY views DESC LIMIT $limit;");
}

function backend_sortByComments($limit) {
  global $db, $site;
  return $db->get_results("SELECT id, subject, comments, DATE_FORMAT(datetime, '$site[date_string]') AS date FROM news ORDER BY comments DESC LIMIT $limit;");
}

function backend_countPostsByTopic() {
  global $db;
  ### first get all user ids ###
  $tid = array();
  $res = $db->get_results("SELECT id, topic_name AS t FROM news_topics ORDER BY id;");
  while($row = $db->next_result(&$res)) {
    $id = $row[id];
    $tid[$id] = $row[t];
  }

  ### get all news for each topic ###
  $tidcount = array();
  foreach($tid as $t_id=>$t) {
    $res = $db->get_results("SELECT id FROM news WHERE topic_id = '$t_id';");
    $tidcount[$t] = count($res);
  }
  return $tidcount;
}

### count posts made by each user id
function backend_countPostsByUser() {
  global $db;
  ### first get all user ids ###
  $uid = array();
  $res = $db->get_results("SELECT id, username AS u FROM usernames");
  while($row = $db->next_result(&$res)) {
    $id = $row[id];
    $uid[$id] = $row[u];
  }

  ### get all news for each user ###
  $uidcount = array();
  foreach($uid as $u_id=>$u) {
    $res = $db->get_results("SELECT id FROM news WHERE user_id = '$u_id';");
    $uidcount[$u] = count($res);
  }
  return $uidcount;
}
?>